@@ -18,8 +18,8 @@
 #ifndef __ANN_ACT_H
 #define __ANN_ACT_H
 
-#include <math.h>
-#include <ctype.h>
+#include <ann_use_size_t.h>
+#include <ann_use_nan.h>
 
 namespace ANN
 {
