@@ -38,21 +38,20 @@ namespace ANN
 
   protected:
     Sink *sink;
-    char *label_in;
-    char *label_des_out;
+    char *label;
     Loc   last;
     bool  active;
 
-    void             log_term();
-    virtual bool     do_reset();
-    virtual void     do_next();
-    virtual bool     do_seek(size_t term_pos_);
-    virtual bool     do_locate(const Loc &loc);
+    void store_term();
 
   public:
-    DS_tee(DS &orig_, Sink &sink_, const char *label_in_=0,
-           const char *label_des_out_=0);
+    DS_tee(DS &orig_, Sink &sink_, const char *label_=0);
     virtual ~DS_tee();
+    
+    virtual bool reset();
+    virtual void feed();
+    virtual bool seek(size_t term_pos_);
+    virtual bool locate(const Loc &loc);
   };
   
 } // namespace ANN
