@@ -18,8 +18,7 @@
 #ifndef __ANN_INIT_H
 #define __ANN_INIT_H
 
-#include <ctype.h>
-
+#include <ann_use_size_t.h>
 #include <ann_loc.h>
 
 namespace ANN
@@ -48,8 +47,8 @@ namespace ANN
 
     const char  *label() const { return buffer; }
     char        *label() { return buffer; }
-    char        *dup_label () const;
-    static char *dup_str (const char *str_);
+    char        *dup_label() const;
+    static char *dup_str(const char *str_);
     size_t       length() const { return len; }
     void         resize(size_t capacity_);
     void         set_label(const char *label, size_t pos=0, char sep='.');
