@@ -21,6 +21,7 @@
 #include <iostream>
 
 #include <ann_tc.h>
+#include <ann_ts.h>
 
 namespace ANN
 {
@@ -33,32 +34,28 @@ namespace ANN
   {
   protected:
 
-    TC      *in;
-    TC      *des_out;
+    TC      *tc;
     TC::Pos  pos_where;
     TC::Pos  pos_loc;
     Loc      where;
     Loc      loc;
-    bool     is_out;
+    size_t   seq;
     bool     was_val;
 
     virtual bool  add_str(const char *str, size_t len);
     virtual void  add_val(double x);
     virtual void  add_line();
-    virtual bool  des_out_patt();
+    virtual void  next_seq();
     virtual bool  internal_parse(std::istream &is);
 
   public:
     Parser_ws();
     virtual ~Parser_ws();
 
-    TC           &input() { return *in; }
-    const TC     &input() const { return *in; }
-    TC           &des_output() { return *des_out; }
-    const TC     &des_output() const { return *des_out; }
-    void          clear(size_t pos=0);
-    bool          parse(std::istream &is);
-    bool          operator() (std::istream &is) { return parse(is); }
+    size_t  get_seq() const { return tc->get_seq(); }
+    TS     *build(size_t seq) { return tc->build(seq); }
+    bool    parse(std::istream &is);
+    bool    operator() (std::istream &is) { return parse(is); }
   };
   
 } // namespace ANN
