@@ -19,6 +19,7 @@
 #define __ANN_TC_H
 
 #include <ann_term.h>
+#include <ann_ts.h>
 
 namespace ANN
 {
@@ -46,50 +47,58 @@ namespace ANN
       bool   dec_level();
       size_t get_level() const { return lev; }
       void   next() { if (lev) ++loc[lev-1]; }
-      void   get_loc(Loc &loc_) const { loc_.resize(lev,loc.coord()); }
+      void   get_loc(Loc &loc_) const { loc_.resize(lev,loc.get_coord()); }
     };
     
   protected:
     struct Token
     {
+      size_t seq;
       Loc    where;
       Loc    loc;
       double val;
-      Token() {}
-      Token(const Loc &w) : where(w) {}
-      Token(const Loc &w, const Loc &l) : where(w), loc(l) {}
-      Token(const Loc &w, const Loc &l, double v)
-      : where(w), loc(l), val(v) {}
+      Token(size_t seq_=0) : seq(seq_) {}
+      Token(const Loc &w, size_t seq_=0) : seq(seq_), where(w) {}
+      Token(const Loc &w, const Loc &l, size_t seq_=0)
+      : seq(seq_), where(w), loc(l) {}
+      Token(const Loc &w, const Loc &l, double v, size_t seq_=0)
+      : seq(seq_), where(w), loc(l), val(v) {}
     };
-    
-    Size length;
-    Size size;
-    bool lim_valid;
+
+    size_t       num_seq;
+    Size         length;
+    Size        *size;    
+    bool         lim_valid;
+    static Size  none;
 
     virtual void do_recalc()=0;
     virtual void do_put(Token &t)=0;
     virtual bool do_get(Token &t)=0;
-    virtual void do_shrink(const Token &t)=0;
-    virtual void do_erase(const Token &t)=0;
+    virtual void do_shrink(Token &t)=0;
+    virtual void do_erase(Token &t)=0;
     virtual void do_clear()=0;    
     void         recalc();
 
   public:
-    TC() : lim_valid(true) {}
+    TC() : num_seq(0), size(0), lim_valid(true) {}
     virtual ~TC();
     
     static TC    *create();
 
     void          expand(Size length_) { recalc(); length.expand(length_); }
+    size_t        get_seq() { recalc(); return num_seq; }
     const Size   &get_lengths() { recalc(); return length; }
     const size_t  get_length() { recalc(); return length.total_size(); }
-    const Size   &get_sizes() { recalc(); return size; }
-    const size_t  get_size() { recalc(); return size.total_size(); }
-    void          put(const Loc &where, const Loc &loc, double val);
-    double        get(const Loc &where, const Loc &loc);
-    Term         *get_term(const Loc &where);
-    void          set_term(const Loc &where, Term &term);
+    const Size   &get_sizes(size_t seq_)
+    { recalc(); return seq_<num_seq ? size[seq_] : none; }
+    const size_t  get_size(size_t seq_)
+    { recalc(); return seq_<num_seq ? size[seq_].total_size() : 0; }
+    void          put(const Loc &where, const Loc &loc, double val, size_t seq=0);
+    double        get(const Loc &where, const Loc &loc, size_t seq=0);
+    TS           *build(size_t seq);
+    void          build(Term &term, const Loc &where, size_t seq);
     void          shrink(const Loc &where);
+    void          erase(const Loc &where, size_t seq);
     void          erase(const Loc &where);
     void          clear();
   };
