@@ -37,8 +37,8 @@ namespace ANN
   public:  
     struct TokenCmp
     { bool operator ()(const Token *t1, const Token *t2) const; };
-    typedef std::set<const Token *,TokenCmp> TokenSet;
-    typedef TokenSet::iterator               TSIterator;
+    typedef std::set<Token *,TokenCmp> TokenSet;
+    typedef TokenSet::iterator         TSIterator;
 
   protected:
     TokenSet tokens;
@@ -46,8 +46,8 @@ namespace ANN
     virtual void do_recalc();
     virtual void do_put(Token &t);
     virtual bool do_get(Token &t);
-    virtual void do_shrink(const Token &t);
-    virtual void do_erase(const Token &t);
+    virtual void do_shrink(Token &t);
+    virtual void do_erase(Token &t);
     virtual void do_clear();
     
   public:
